# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"S3": "s3bz.ipynb"}

modules = ["s3bz.py"]

doc_url = "https://fastai.github.io/nbdev_template/"

git_url = "https://github.com/fastai/nbdev_template/tree/master/"

def custom_doc_links(name): return None
